==> RecalAddon4.2.jar: addon/alienevo/kubejs_scripts/alien_codex.js <==
global.watch_palette_ult = ["b3ff40", "a7f72e", "8ed721", "77b81a", "639d11"];
global.watch_palette_recal_watch_active_glow = ["b3ff40", "438000", "90c913", "65c100", "639d11"];

global.watch_palette_ult_uniform_primary = ["3a3333", "2c2828", "232020", "171515", "000000"];
global.watch_palette_ult_uniform_secondary = ["ffffff", "edf4f4", "d6dfe1", "bdc7cf", "97a2b0"];

global.watch_palette_completed = ["b3ff40", "a7f72e", "8ed721", "77b81a", "639d11"];



global.alienevo_alien_31 = ['alienevo_aliens:methanosian'] //Swampfire
global.alienevo_regen_31 = [7];  // Swampfire
global.alienevo_background_31 = ['minecraft:textures/block/dirt.png'];
global.alienevo_randomization_31 = [true];  // Swampfire

global.alienevo_31_10k_uniforms = [true, false, false]; 
global.alienevo_31_default_uniforms = [true, false, false]; 
global.alienevo_31_prototype_uniforms = [true, false, false];

global.alienevo_31_prototype_skincolor_palette_1 = ["73864c", "61723f", "4e5f30", "3e4b24", "323e1b"];
global.alienevo_31_prototype_skincolor_palette_2 = ["c80f12", "af071c", "920920", "7c0525", "33090d"];
global.alienevo_31_prototype_skincolor_palette_3 = ["f4cb4b", "e2b741", "cf9a30", "c2852a", "b37125"];

global.alienevo_31_default_skincolor_palette_1 = ["73864c", "61723f", "4e5f30", "3e4b24", "323e1b"];
global.alienevo_31_default_skincolor_palette_2 = ["c80f12", "af071c", "920920", "7c0525", "33090d"];
global.alienevo_31_default_skincolor_palette_3 = ["f4cb4b", "e2b741", "cf9a30", "c2852a", "b37125"];

global.alienevo_31_10k_skincolor_palette_1 = ["73864c", "61723f", "4e5f30", "3e4b24", "323e1b"];
global.alienevo_31_10k_skincolor_palette_2 = ["c80f12", "af071c", "920920", "7c0525", "33090d"];
global.alienevo_31_10k_skincolor_palette_3 = ["f4cb4b", "e2b741", "cf9a30", "c2852a", "b37125"];



























global.watch_palette_recal_10k_uniforms = [true, true, true];
global.watch_palette_recal_default_uniforms = [true, true, true];
global.watch_palette_recal_prototype_uniforms = [true, true, true];
global.watch_palette_recal_default_skincolor_palette_1 = ["3a3333", "2c2828", "232020", "171515", "000000"];
global.watch_palette_recal_2_uniform_secondary = ["56b60c", "40a009", "288204", "196902", "0D5100"];
global.watch_palette_ult_uniform_primary = ["3b8923"];
global.watch_palette_ult_uniform_secondary = ["8ed721"];
global.watch_palette_recal_2 = ["3a3333", "2c2828", "232020", "171515", "000000"];

==> RecalAddon4.7.jar: addon/alienevo/kubejs_scripts/alien_codex.js <==
global.watch_palette_ult = ["b3ff40", "a7f72e", "8ed721", "77b81a", "639d11"];
global.watch_palette_recal_watch_active_glow = ["b3ff40", "438000", "90c913", "65c100", "639d11"];

global.watch_palette_ult_uniform_primary = ["3a3333", "2c2828", "232020", "171515", "000000"];
global.watch_palette_ult_uniform_secondary = ["ffffff", "edf4f4", "d6dfe1", "bdc7cf", "97a2b0"];

global.watch_palette_completed = ["b3ff40", "a7f72e", "8ed721", "77b81a", "639d11"];



global.alienevo_alien_31 = ['alienevo_aliens:methanosian'] //Swampfire
global.alienevo_regen_31 = [7];  // Swampfire
global.alienevo_background_31 = ['minecraft:textures/block/dirt.png'];
global.alienevo_randomization_31 = [true];  // Swampfire

global.alienevo_31_10k_uniforms = [true, false, false]; 
global.alienevo_31_default_uniforms = [true, false, false]; 
global.alienevo_31_prototype_uniforms = [true, false, false];

global.alienevo_31_prototype_skincolor_palette_1 = ["73864c", "61723f", "4e5f30", "3e4b24", "323e1b"];
global.alienevo_31_prototype_skincolor_palette_2 = ["c80f12", "af071c", "920920", "7c0525", "33090d"];
global.alienevo_31_prototype_skincolor_palette_3 = ["f4cb4b", "e2b741", "cf9a30", "c2852a", "b37125"];

global.alienevo_31_default_skincolor_palette_1 = ["73864c", "61723f", "4e5f30", "3e4b24", "323e1b"];
global.alienevo_31_default_skincolor_palette_2 = ["c80f12", "af071c", "920920", "7c0525", "33090d"];
global.alienevo_31_default_skincolor_palette_3 = ["f4cb4b", "e2b741", "cf9a30", "c2852a", "b37125"];

global.alienevo_31_10k_skincolor_palette_1 = ["73864c", "61723f", "4e5f30", "3e4b24", "323e1b"];
global.alienevo_31_10k_skincolor_palette_2 = ["c80f12", "af071c", "920920", "7c0525", "33090d"];
global.alienevo_31_10k_skincolor_palette_3 = ["f4cb4b", "e2b741", "cf9a30", "c2852a", "b37125"];

global.alienevo_31_10k_glowcolor_1 = ["f8c144", "df8c13"];
global.alienevo_31_default_glowcolor_1 = ["b3ff40", "8ed721"];
global.alienevo_31_prototype_glowcolor_1 = ["f8c144", "df8c13"];






























global.watch_palette_recal_10k_uniforms = [true, true, true];
global.watch_palette_recal_default_uniforms = [true, true, true];
global.watch_palette_recal_prototype_uniforms = [true, true, true];
global.watch_palette_recal_default_skincolor_palette_1 = ["3a3333", "2c2828", "232020", "171515", "000000"];
global.watch_palette_recal_2_uniform_secondary = ["56b60c", "40a009", "288204", "196902", "0D5100"];
global.watch_palette_ult_uniform_primary = ["3b8923"];
global.watch_palette_ult_uniform_secondary = ["8ed721"];
global.watch_palette_recal_2 = ["3a3333", "2c2828", "232020", "171515", "000000"];
